@@ -1,4 +1,6 @@
 #' Schmildt's genotypic confidence index
+#' @description
+#' `r badge('stable')`
 #'
 #' Stability analysis using the known genotypic confidence index (Annicchiarico,
 #' 1992) modified by Schmildt et al. 2011.
@@ -11,13 +13,13 @@
 #' @param rep The name of the column that contains the levels of the
 #'   replications/blocks
 #' @param resp The response variable(s). To analyze multiple variables in a
-#'   single procedure use, for example, \code{resp = c(var1, var2, var3)}.
+#'   single procedure use, for example, `resp = c(var1, var2, var3)`.
 #' @param prob The probability of error assumed.
-#' @param verbose Logical argument. If \code{verbose = FALSE} the code will run
+#' @param verbose Logical argument. If `verbose = FALSE` the code will run
 #'   silently.
 #' @author Tiago Olivoto, \email{tiagoolivoto@@gmail.com}
-#' @seealso \code{\link{superiority}, \link{ecovalence}, \link{ge_stats},
-#'   \link{Annicchiarico}}
+#' @seealso [superiority()], [ecovalence()], [ge_stats()],
+#'   [Annicchiarico()]
 #' @references
 #' Annicchiarico, P. 1992. Cultivar adaptation and recommendation from alfalfa
 #' trials in Northern Italy. J. Genet. Breed. 46:269-278.
@@ -29,13 +31,13 @@
 #' @return
 #' A list where each element is the result for one variable and contains the
 #' following data frames:
-#' * \strong{environments} Contains the mean, environmental index and
+#' * **environments** Contains the mean, environmental index and
 #' classification as favorables and unfavorables environments.
-#' * \strong{general} Contains the genotypic confidence index considering all
+#' * **general** Contains the genotypic confidence index considering all
 #' environments.
-#' * \strong{favorable} Contains the genotypic confidence index considering
+#' * **favorable** Contains the genotypic confidence index considering
 #' favorable environments.
-#' * \strong{unfavorable} Contains the genotypic confidence index considering
+#' * **unfavorable** Contains the genotypic confidence index considering
 #' unfavorable environments.
 #' @md
 #' @export
@@ -64,9 +66,7 @@ Schmildt <- function(.data, env, gen, rep, resp, prob = 0.05,
   listres <- list()
   nvar <- ncol(vars)
   if (verbose == TRUE) {
-    pb <- progress_bar$new(
-      format = "Evaluating the variable :what [:bar]:percent",
-      clear = FALSE, total = nvar, width = 90)
+    pb <- progress(max = nvar, style = 4)
   }
   for (var in 1:nvar) {
     data <- factors %>%
@@ -112,7 +112,9 @@ Schmildt <- function(.data, env, gen, rep, resp, prob = 0.05,
                  favorable = favorable,
                  unfavorable = unfavorable)
     if (verbose == TRUE) {
-      pb$tick(tokens = list(what = names(vars[var])))
+      run_progress(pb,
+                   actual = var,
+                   text = paste("Evaluating trait", names(vars[var])))
     }
     listres[[paste(names(vars[var]))]] <- temp
   }
@@ -123,18 +125,18 @@ NULL
 
 #' Print an object of class Schmildt
 #'
-#' Print the \code{Schmildt} object in two ways. By default, the results
+#' Print the `Schmildt` object in two ways. By default, the results
 #' are shown in the R console. The results can also be exported to the directory
 #' into a *.txt file.
 #'
 #'
-#' @param x The \code{Schmildt} x
-#' @param export A logical argument. If \code{TRUE}, a *.txt file is exported to
+#' @param x The `Schmildt` x
+#' @param export A logical argument. If `TRUE`, a *.txt file is exported to
 #'   the working directory.
-#' @param file.name The name of the file if \code{export = TRUE}
+#' @param file.name The name of the file if `export = TRUE`
 #' @param digits The significant digits to be shown.
 #' @param ... Options used by the tibble package to format the output. See
-#'   \code{\link[tibble]{formatting}} for more details.
+#'   [tibble::formatting()] for more details.
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @method print Schmildt
 #' @export
