@@ -330,15 +330,23 @@ waas <- function(.data,
             max_group <- Escores %>% group_by(type) %>% top_n(1, Y) %>% select(type, Code, Y) %>% slice(1) %>% as.data.frame()
             min <- MeansGxE %>% top_n(1, -Y) %>% select(ENV, GEN, Y) %>% slice(1)
             max <- MeansGxE %>% top_n(1, Y) %>% select(ENV, GEN, Y) %>% slice(1)
-            Details <- tibble(Parameters = c("Ngen", "Nenv", "OVmean","Min", "Max", "MinENV", "MaxENV", "MinGEN", "MaxGEN", "SigPC"),
-                              Values = c(Ngen, Nenv, round(mean(MeansGxE$Y), 4),
-                                         paste0(round(min[3], 4), " (", min$GEN, " in ", min$ENV,")"),
-                                         paste0(round(max$Y, 4), " (", max$GEN, " in ", max$ENV,")"),
-                                         paste0(min_group[1,2], " (", round(min_group[1,3], 3),")"),
-                                         paste0(max_group[1,2], " (", round(max_group[1,3], 3),")"),
-                                         paste0(min_group[2,2], " (", round(min_group[2,3], 3), ") "),
-                                         paste0(max_group[2,2], " (", round(max_group[2,3], 3), ") "),
-                                         SigPC1))
+            Details <-
+                rbind(ge_details(data, ENV, GEN, Y),
+                      tribble(~Parameters,  ~Y,
+                              "wresp", PesoResp[vin],
+                              "mresp", mresp[vin],
+                              "Ngen", Ngen,
+                              "Nenv", Nenv)) %>%
+                rename(Values = Y)
+            # Details <- tibble(Parameters = c("Ngen", "Nenv", "OVmean","Min", "Max", "MinENV", "MaxENV", "MinGEN", "MaxGEN", "SigPC"),
+            #                   Values = c(Ngen, Nenv, round(mean(MeansGxE$Y), 4),
+            #                              paste0(round(min[3], 4), " (", min$GEN, " in ", min$ENV,")"),
+            #                              paste0(round(max$Y, 4), " (", max$GEN, " in ", max$ENV,")"),
+            #                              paste0(min_group[1,2], " (", round(min_group[1,3], 3),")"),
+            #                              paste0(max_group[1,2], " (", round(max_group[1,3], 3),")"),
+            #                              paste0(min_group[2,2], " (", round(min_group[2,3], 3), ") "),
+            #                              paste0(max_group[2,2], " (", round(max_group[2,3], 3), ") "),
+            #                              SigPC1))
             listres[[paste(names(vars[var]))]] <-
                 structure(list(individual = individual[[1]],
                                model = WAASAbs,
